require 'rspec'
require File.dirname(__FILE__) + '/../lib/WxAlert'

RSpec.describe WxAlert do

  describe '.new_idx' do
    # These tests mostly test return values/types
    # Actual behavior of the AlertsIndex is in the
    # alertsindex_spec.rb file
    context 'valid code used' do
      before(:all) do
        @valid_index = WxAlert.new_idx('us')
      end

      it 'should return an AlertsIndex' do
        expect(@valid_index).to be_a WxAlert::AlertsIndex
      end

      it 'should be fixed' do
        expect(@valid_index.fixed).to be true
      end
    end

    context 'invalid code used' do
      before(:all) do
        @valid_index = WxAlert.new_idx('New Zealand')
      end

      it 'should return an AlertsIndex' do
        expect(@valid_index).to be_a WxAlert::AlertsIndex
      end

      it 'should not be fixed' do
        expect(@valid_index.fixed).to be false
      end

      it 'should contain the error string' do
        expect(@valid_index.index).to eq(['Error'])
      end
    end
  end

  describe '.set_idx_code' do
    context 'any code used' do
      before(:all) do
        @set_index = WxAlert.set_idx_code('us')
      end

      it 'should return an AlertsIndex' do
        expect(@set_index).to be_a WxAlert::AlertsIndex
      end

      it 'should not be fixed' do
        expect(@set_index.fixed).to be false
      end
    end
  end

  describe '.valid_code?' do
    context 'valid code is used' do
      # Colorado
      describe 'state code' do
        it { expect(WxAlert.valid_code?('co')).to be true}
      end

      # Denver Metro area(ish)
      describe 'UGC code' do
        it { expect(WxAlert.valid_code?('COZ040')).to be true}
      end

      # Multnomah County, OR
      describe 'FIPS country code' do
        it { expect(WxAlert.valid_code?('ORC051')).to be true}
      end
    end

    context 'invalid code is used' do
      describe 'state code' do
        it { expect(WxAlert.valid_code?('qz')).to be false}
      end

      describe 'UGC code' do
        it { expect(WxAlert.valid_code?('COZ432')).to be false}
      end

      describe 'FIPS country code' do
        it { expect(WxAlert.valid_code?('ORC951')).to be false}
      end

      describe 'nonsense' do
        it { expect(WxAlert.valid_code?('strong badia')).to be false}
      end
    end
  end
end